==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/it/general.php <==
<?php

    return [
    'accessories'			=> 'Accessori',
    'activated'			    => 'Attivato',
    'accessory'				=> 'Accessorio',
    'accessory_report'		=> 'Rapporto sugli Accessori',
    'action'                => 'Azione',
    'activity_report'		=> 'Rapporto sull\'attività',
    'address'				=> 'Indirizzo',
    'admin'					=> 'Amministratore',
    'administrator'			=> 'Amministratore',
    'add_seats'             => 'Aggiunti posti',
    'all_assets'			=> 'Tutti i Beni',
    'all'       			=> 'Tutti i',
    'archived'              => 'Archiviato',
    'asset_models'			=> 'Modello Bene',
    'asset_model'			=> 'Modello',
    'asset'					=> 'Bene',
    'asset_report'          => 'Report beni',
    'asset_tag'				=> 'Tag Bene',
    'assets_available'		=> 'beni disponibili',
    'audit'				    => 'revisione',
    'audit_report'			=> 'Registro di controllo',
    'assets'				=> 'Beni',
    'avatar_delete'         => 'Cancella Avatar',
    'avatar_upload'         => 'Carica Avatar',
    'back'      			=> 'Indietro',
    'bad_data'      		=> 'Non è stato trovato nulla. Forse informazioni errate?',
    'bulkaudit'             => 'Audit di massa',
    'bulkaudit_status'      => 'Stato di controllo',
    'bulk_checkout'  		=> 'Checkout Bulk',
    'bystatus'              => 'in base allo stato',
    'cancel'  				=> 'annulla',
    'categories'			=> 'Categorie',
    'category'				=> 'Categoria',
    'change' 		        => 'Dentro fuori',
    'changeemail'  			=> 'Modifica indirizzo email',
    'changepassword'  		=> 'Modifica password',
    'checkin'  				=> 'Carica',
    'checkin_from'  		=> 'Carica da',
    'checkout'  			=> 'Scarica',
    'checkouts_count'       => 'Ritiri',
    'checkins_count'        => 'Consegne',
    'user_requests_count'   => 'Richieste',
    'city'  				=> 'Città',
	'click_here'			=> 'Clicca qui',
    'clear_selection'		=> 'Annulla selezione',
    'companies'			    => 'Aziende',
    'company'				=> 'Azienda',
    'component'			    => 'Componente',
    'components'			=> 'Componenti',
	'complete'				=> 'Completare',
    'consumable'			=> 'Consumabile',
    'consumables'			=> 'Consumabili',
    'country'  				=> 'Paese',
    'create'				=> 'Crea',
    'created'               => 'Articolo creato',
    'created_asset'			=> 'Asset creato',
    'created_at' 			=> 'Creato il',
    'record_created' 		=> 'Record creato',
    'updated_at' 			=> 'Aggiornato a',
    'currency'  			=> '$', // this is deprecated
    'current'  				=> 'Attuale',
    'custom_report'         => 'Report assets personalizzato',
    'dashboard'				=> 'Pannello amministrativo',
    'days'      			=> 'giorni',
    'days_to_next_audit'    => 'Giorni per il controllo successivo',
    'date'					=> 'Data',
    'debug_warning'         => 'Avvertimento!',
    'debug_warning_text'    => 'Questa applicazione è in esecuzione in modalità di produzione con il debug abilitato. Questo può esporre dati sensibili se l\'applicazione è accessibile al mondo esterno. Disabilitare la modalità di debug impostando il valore <code>APP_DEBUG</code> nel file <code>.env</code> a <code>false</code>.',
    'delete'  				=> 'elimina',
    'delete_confirm'  		=> 'Sei sicuro di voler eliminare :item?',
    'deleted'  				=> 'Eliminata',
    'delete_seats'  		=> 'Posti Cancellati',
    'departments'           => 'dipartimenti',
    'department'           => 'Dipartimento',
    'deployed'				=> 'Distribuita',
    'depreciation_report'	=> 'Report degli Obsoleti',
    'details'               => 'Dettagli',
    'download'				=> 'Scarica',
    'download_all'				=> 'Scarica tutto',
    'depreciation'			=> 'Obsoleti',
    'editprofile'  			=> 'Edita il tuo profilo',
    'eol'					=> 'EOL',
    'email_domain'			=> 'Dominio di posta elettronica',
    'email_format'			=> 'Formato di posta elettronica',
    'email_domain_help'		=> 'Questo viene utilizzato per generare indirizzi e-mail durante l\'importazione',
    'filastname_format'			=> 'Prima cognome iniziale (jsmith@example.com)',
    'firstname_lastname_format'	=> 'Nome cognome (jane.smith@example.com)',
    'firstname_lastname_underscore_format' => 'Nome cognome (jane.smith@example.com)',
    'lastnamefirstinitial_format' =>  'Cognome e Prima iniziale (prossi@esempio.it)',
    'firstintial_dot_lastname_format' => 'Iniziale del nome e cognome (j.smith@example.com)',
    'first'					=> 'Primo',
    'firstnamelastname'     => 'Nome e cognome (janesmith@example.com)',
    'lastname_firstinitial' => 'Cognome e iniziale del nome (smith_j@example.com)',
    'firstinitial.lastname' => 'Iniziale del nome e cognome (j.smith@example.com)',
    'firstnamelastinitial'  => 'Nome e iniziale del cognome (janes@example.com)',
    'first_name'			=> 'Nome',
    'first_name_format'		=> 'Nome (jane@example.com)',
    'files'                 => 'Files',
    'file_name'				=> 'File',
    'file_type'             => 'Tipo di file',
    'file_uploads'			=> 'Carica i file',
    'generate'				=> 'Genera',
     'github_markdown'      => 'Questo campo consente a <a href="https://help.github.com/articles/github-flavored-markdown/">Markdown Github</a>.',
    'groups'				=> 'Gruppi',
    'gravatar_email'        => 'Indirizzo Email Gravatar',
    'history'  			    => 'Storia',
    'history_for'  			=> 'Cronologia',
    'id'  					=> 'ID',
    'image'                 => 'Immagine',
    'image_delete'         	=> 'Cancella l\'Immagine',
    'image_upload'         	=> 'Carica immagine',
    'image_filetypes_help'  => 'I tipi di file accettati sono jpg, webp, png, gif e svg. La dimensione massima consentita per il caricamento è :size.',
    'import'         	    => 'Importa',
    'importing'         	=> 'Importare',
    'importing_help'        => 'È possibile importare risorse, accessori, licenze, componenti, materiali di consumo e utenti utilizzando file CSV. <br><br>Il CSV dovrebbe essere delimitato e formattato con elementi che corrispondano a quelle della seguente documentazione <a href="https://snipe-it.readme.io/docs/importing" target="_new"> esempio CSV </a>.',
    'import-history'        => 'Storia di importazione',
    'asset_maintenance'        => 'Manutenzione Prodotto',
    'asset_maintenance_report' => 'Rapporto manutenzione prodotto',
    'asset_maintenances'       => 'Manutenzione Prodotto',
    'item'  				=> 'Articolo',
    'insufficient_permissions' => 'Permessi Insufficienti!',
    'kits'       			=> 'Kit Predefiniti',
    'language'				=> 'Lingua',
    'last'					=> 'Ultimo',
    'last_login'            => 'Ultimo accesso',
    'last_name'             => 'Cognome',
    'license'				=> 'Licenza',
    'license_report'        => 'Report Licenze',
    'licenses_available'	=> 'Licenze Disponibili',
    'licenses'				=> 'Licenze',
    'list_all'				=> 'Visualizza Tutti',
    'loading'				=> 'Caricamento',
    'lock_passwords'        => 'Questo valore non verrà salvato in un\'installazione demo.',
    'feature_disabled'      => 'Questa funzionalità è stata disabilitata per l\'installazione demo.',
    'location'              => 'Luogo',
    'locations'				=> 'Luoghi',
    'logo_size'				=> 'I loghi quadrati appaiono meglio con Logo + Testo. La dimensione massima del in pixel è di 50px in altezza e 500px in larghezza.  ',
    'logout'				=> 'logout',
    'lookup_by_tag'     => 'Ricerca da Asset Tag',
    'maintenances'          => 'Manutenzioni',
    'manufacturer'			=> 'Produttore',
    'manufacturers'			=> 'Produttori',
    'markdown'				=> 'Questo campo consente a <a href="https://help.github.com/articles/github-flavored-markdown/">Gridubdown flavored markdown</a>.',
    'min_amt'				=> 'Min. QTY',
    'min_amt_help'	=> 'Numero minimo di elementi che dovrebbero essere disponibili prima che un avviso venga attivato.',
    'model_no'				=> 'Modello No.',
    'months'				=> 'mesi',
    'moreinfo'				=> 'Altre informazioni',
    'name'					=> 'Nome',
    'next'					=> 'Successivo',
    'next_audit_date'		=> 'Prossima data di verifica',
    'last_audit'		    => 'Ultimo controllo',
    'new'					=> 'nuovo!',
    'no_depreciation'		=> 'Non Obsololeto',
    'no_results'			=> 'Nessun risultato.',
    'no'  					=> 'No',
    'notes'  				=> 'Note',
    'order_number'          => 'Numero d\'ordine',
    'page_menu'				=> 'Visualizza _MENU_Items',
    'pagination_info'		=> 'Visualizza _START_ to _END_ of _TOTAL_ articoli',
    'pending'				=> 'In attesa',
    'people'				=> 'Utenti',
    'per_page'				=> 'Risultati per Pagina',
    'previous'				=> 'Precedente',
    'processing'			=> 'In elaborazione',
    'profile'				=> 'Il tuo profilo',
    'purchase_cost'                              => 'Prezzo d\'acquisto',
    'purchase_date'         => 'Data di acquisto',
    'qty'		            => 'Quantità',
    'quantity'		        => 'Quantità',
    'ready_to_deploy'		=> 'Pronto per il rilascio',
    'recent_activity'		=> 'Attività Recenti',
    'remove_company'        => 'Rimuovi associazioni azienda',
    'reports'				=> 'Reports',
    'restored'				=> 'ripristinato',
    'requested'				=> 'Richiesto',
    'request_canceled'      => 'Richiesta annullata',
    'save'  				=> 'Salva',
    'select'				=> 'Seleziona',
    'search'				=> 'Cerca',
    'select_category'       => 'Seleziona una categoria',
    'select_department'       => 'Seleziona un Dipartimento',
    'select_depreciation'	=> 'Selezionare un tipo di ammortamento',
    'select_location'		=> 'Seleziona una posizione',
    'select_manufacturer'	=> 'Selezionare un produttore',
    'select_model'			=> 'Selezionare un modello',
    'select_supplier'		=> 'Selezionare un fornitore',
    'select_user'			=> 'Selezionare un utente',
    'select_date'			=> 'Seleziona la data (YYYY-MM-DD)',
    'select_statuslabel'	=> 'Seleziona stato',
    'select_company'    	=> 'Seleziona Azienda',
    'select_asset'    		=> 'Seleziona Asset',
    'settings'				=> 'Impostazioni',
    'show_deleted'  		=> 'Mostra Eliminati',
    'show_current'  		=> 'Visualizza corrente',
    'sign_in'				=> 'Accedi',
    'signature'             => 'Firma',
    'skin'       			=> 'Tema',
    'slack_test_msg'        => 'Oh hai! Sembra che la tua integrazione Slack con Snipe-IT funziona!',
    'some_features_disabled' => 'DEMO: Alcune caratteristiche sono disabilitate in questa modalità.',
    'site_name'				=> 'Nome sito',
    'state'  				=> 'Stato',
    'status_labels'			=> 'Etichetta di Stato',
    'status'    			=> 'Stato',
    'supplier'              => 'Fornitore',
    'suppliers'  			=> 'Fornitori',
    'sure_to_delete'    => 'Sei sicuro di voler eliminare',
    'submit'				=> 'Invia',
    'target'                => 'Assegnatario',
    'time_and_date_display' => 'Visualizzazione del tempo e del tempo',
    'total_assets'			=> 'Assets totali',
    'total_licenses'		=> 'Totale licenze',
    'total_accessories'		=> 'accessori totali',
    'total_consumables'		=> 'consumabili totali',
    'type'  				=> 'Tipo',
    'undeployable'			=> 'Non consegnabile',
    'unknown_admin'			=> 'Amministratore sconosciuto',
    'username_format'		=> 'Formato di nome utente',
    'update'                => 'Aggiorna',
    'upload_filetypes_help'      => 'I tipi di file permessi sono png, gif, jpg, jpeg, doc, docx, pdf, xls, txt, lic, zip, e rar. La dimensione massima di upload è di :size.',
    'uploaded'              => 'Caricato',
    'user'					=> 'Utente',
    'accepted'			    => 'accettato',
    'declined'			    => 'rifiutato',
    'unaccepted_asset_report' => 'Prodotti non accettati',
    'users'                 => 'Utenti',
    'viewall'				=> 'Visualizza tutto',
    'viewassets'  			=> 'Visualizza gli Assets assegnati',
    'website'               => 'Sito Web',
    'welcome'				=> 'Benvenuto, :name',
    'years'					=> 'anni',
    'yes' 					=> 'SÌ',
    'zip'  					=> 'Zip',
    'noimage'				=> 'Nessuna immagine caricata o immagine non trovata.',
    'token_expired'         => 'La sessione di modulo è scaduta. Riprova.',
    'login_enabled'         => 'Login Abilitato',
    'audit_due'             => 'In scadenza per l\'audit',
    'audit_overdue'         => 'Scaduto per l\'audit',
    'accept'                => 'Accetta :asset',
    'i_accept'              => 'Accetto',
    'i_decline'             => 'Rifiuto',
    'sign_tos'              => 'Firma qui sotto per indicare che accetti i termini di servizio:',
    'clear_signature'       => 'Cancella Firma',
    'show_help'             => 'Mostra aiuto',
    'hide_help'             => 'Nascondi aiuto',
    ];

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/it/general.php <==
<?php

    return [
    'accessories'			=> 'Accessori',
    'activated'			    => 'Attivato',
    'accessory'				=> 'Accessorio',
    'accessory_report'		=> 'Rapporto sugli Accessori',
    'action'                => 'Azione',
    'activity_report'		=> 'Rapporto sull\'attività',
    'address'				=> 'Indirizzo',
    'admin'					=> 'Amministratore',
    'administrator'			=> 'Amministratore',
    'add_seats'             => 'Aggiunti posti',
    'all_assets'			=> 'tutti i beni',
    'all'       			=> 'Tutti i',
    'archived'              => 'Archiviato',
    'asset_models'			=> 'Modello Bene',
    'asset_model'			=> 'Modello',
    'asset'					=> 'Bene',
    'asset_report'          => 'Report beni',
    'asset_tag'				=> 'Tag Bene',
    'asset_tags'            => 'Asset Tags',
    'assets_available'		=> 'Assets available',
    'accept_assets'         => 'Accept Assets :name',
    'accept_assets_menu'    => 'Accept Assets',
    'audit'				    => 'revisione',
    'audit_report'			=> 'Registro di controllo',
    'assets'				=> 'Beni',
    'avatar_delete'         => 'Cancella Avatar',
    'avatar_upload'         => 'Carica Avatar',
    'back'      			=> 'Indietro',
    'bad_data'      		=> 'Non è stato trovato nulla. Forse informazioni errate?',
    'bulkaudit'             => 'Audit di massa',
    'bulkaudit_status'      => 'Stato di controllo',
    'bulk_checkout'  		=> 'Checkout Bulk',
    'bulk_edit'             => 'Modifica in blocco',
    'bulk_delete'           => 'Bulk Delete',
    'bulk_actions'          => 'Bulk Actions',
    'bulk_checkin_delete'   => 'Bulk Checkin &amp; Delete',
    'bystatus'              => 'in base allo stato',
    'cancel'  				=> 'annulla',
    'categories'			=> 'Categorie',
    'category'				=> 'Categoria',
    'change' 		        => 'Dentro fuori',
    'changeemail'  			=> 'Modifica indirizzo email',
    'changepassword'  		=> 'Modifica password',
    'checkin'  				=> 'Carica',
    'checkin_from'  		=> 'Carica da',
    'checkout'  			=> 'Scarica',
    'checkouts_count'       => 'Ritiri',
    'checkins_count'        => 'Consegne',
    'user_requests_count'   => 'Richieste',
    'city'  				=> 'Città',
    'click_here'			=> 'Clicca qui',
    'clear_selection'		=> 'Annulla selezione',
    'companies'			    => 'Aziende',
    'company'				=> 'Azienda',
    'component'			    => 'Componente',
    'components'			=> 'Componenti',
    'complete'				=> 'Completare',
    'consumable'			=> 'Consumabile',
    'consumables'			=> 'Consumabili',
    'country'  				=> 'Paese',
    'create'				=> 'Crea',
    'created'               => 'Articolo creato',
    'created_asset'			=> 'Asset creato',
    'created_at' 			=> 'Creato il',
    'record_created' 		=> 'Record creato',
    'updated_at' 			=> 'Aggiornato a',
    'currency'  			=> '$', // this is deprecated
    'current'  				=> 'Attuale',
    'current_password'      => 'Password attuale',
    'customize_report'      => 'Personalizza Report',
    'custom_report'         => 'Report assets personalizzato',
    'dashboard'				=> 'Pannello amministrativo',
    'days'      			=> 'giorni',
    'days_to_next_audit'    => 'Giorni per il controllo successivo',
    'date'					=> 'Data',
    'debug_warning'         => 'Avvertimento!',
    'debug_warning_text'    => 'Questa applicazione è in esecuzione in modalità di produzione con il debug abilitato. Questo può esporre dati sensibili se l\'applicazione è accessibile al mondo esterno. Disabilitare la modalità di debug impostando il valore <code>APP_DEBUG</code> nel file <code>.env</code> a <code>false</code>.',
    'delete'  				=> 'elimina',
    'delete_confirm'  		=> 'Sei sicuro di voler eliminare :item?',
    'deleted'  				=> 'Eliminata',
    'delete_seats'  		=> 'Posti Cancellati',
    'deletion_failed'       => 'Eliminazione fallita',
    'departments'           => 'dipartimenti',
    'department'            => 'Dipartimento',
    'deployed'				=> 'Distribuita',
    'depreciation'			=> 'Obsoleti',
    'depreciations'         => 'Depreciations',
    'depreciation_report'	=> 'Report degli Obsoleti',
    'details'               => 'Dettagli',
    'download'				=> 'Scarica',
    'download_all'		    => 'Scarica tutto',
    'editprofile'  			=> 'Edita il tuo profilo',
    'eol'					=> 'EOL',
    'email_domain'			=> 'Dominio di posta elettronica',
    'email_format'			=> 'Formato di posta elettronica',
    'employee_number'       => 'Numero Dipendente',
    'email_domain_help'		=> 'Questo viene utilizzato per generare indirizzi e-mail durante l\'importazione',
    'error'				    => 'Errore',
    'filastname_format'			=> 'Prima cognome iniziale (jsmith@example.com)',
    'firstname_lastname_format'	=> 'Nome cognome (jane.smith@example.com)',
    'firstname_lastname_underscore_format' => 'Nome cognome (jane.smith@example.com)',
    'lastnamefirstinitial_format' =>  'Cognome e Prima iniziale (prossi@esempio.it)',
    'firstintial_dot_lastname_format' => 'Iniziale del nome e cognome (j.smith@example.com)',
    'first'					=> 'Primo',
    'firstnamelastname'     => 'Nome e cognome (janesmith@example.com)',
    'lastname_firstinitial' => 'Cognome e iniziale del nome (smith_j@example.com)',
    'firstinitial.lastname' => 'Iniziale del nome e cognome (j.smith@example.com)',
    'firstnamelastinitial'  => 'Nome e iniziale del cognome (janes@example.com)',
    'first_name'			=> 'Nome',
    'first_name_format'		=> 'Nome (jane@example.com)',
    'files'                 => 'Files',
    'file_name'				=> 'File',
    'file_type'             => 'Tipo di file',
    'file_uploads'			=> 'Carica i file',
    'file_upload'           => 'File Upload',
    'generate'				=> 'Genera',
    'generate_labels'       => 'Genera Etichette',
    'github_markdown'      => 'Questo campo consente a <a href="https://help.github.com/articles/github-flavored-markdown/">Markdown Github</a>.',
    'groups'				=> 'Gruppi',
    'gravatar_email'        => 'Indirizzo Email Gravatar',
    'gravatar_url'          => '<a href="http://gravatar.com"><small>Change your avatar at Gravatar.com</small></a>.',
    'history'  			    => 'Storia',
    'history_for'  			=> 'Cronologia',
    'id'  					=> 'ID',
    'image'                 => 'Immagine',
    'image_delete'         	=> 'Cancella l\'Immagine',
    'image_upload'         	=> 'Carica immagine',
    'filetypes_accepted_help'    => 'Accepted filetype is :types. Max upload size allowed is :size.|Accepted filetypes are :types. Max upload size allowed is :size.',
    'filetypes_size_help'   => 'Max upload size allowed is :size.',
    'image_filetypes_help'  => 'I tipi di file accettati sono jpg, webp, png, gif e svg. La dimensione massima consentita per il caricamento è :size.',
    'import'         	    => 'Importa',
    'importing'         	=> 'Importare',
    'importing_help'        => 'È possibile importare risorse, accessori, licenze, componenti, materiali di consumo e utenti utilizzando file CSV. <br><br>Il CSV dovrebbe essere delimitato e formattato con elementi che corrispondano a quelle della seguente documentazione <a href="https://snipe-it.readme.io/docs/importing" target="_new"> esempio CSV </a>.',
    'import-history'        => 'Storia di importazione',
    'asset_maintenance'        => 'Manutenzione Prodotto',
    'asset_maintenance_report' => 'Rapporto manutenzione prodotto',
    'asset_maintenances'       => 'Manutenzione Prodotto',
    'item'  				=> 'Articolo',
    'item_name'             => 'Item Name',
    'insufficient_permissions' => 'Permessi Insufficienti!',
    'kits'       			=> 'Kit Predefiniti',
    'language'				=> 'Lingua',
    'last'					=> 'Ultimo',
    'last_login'            => 'Ultimo accesso',
    'last_name'             => 'Cognome',
    'license'				=> 'Licenza',
    'license_report'        => 'Report Licenze',
    'licenses_available'	=> 'Licenze Disponibili',
    'licenses'				=> 'Licenze',
    'list_all'				=> 'Visualizza Tutti',
    'loading'				=> 'Caricamento... attendere prego....',
    'lock_passwords'        => 'Questo valore non verrà salvato in un\'installazione demo.',
    'feature_disabled'      => 'Questa funzionalità è stata disabilitata per l\'installazione demo.',
    'location'              => 'Luogo',
    'locations'				=> 'Luoghi',
    'logo_size'				=> 'I loghi quadrati appaiono meglio con Logo + Testo. La dimensione massima del in pixel è di 50px in altezza e 500px in larghezza.  ',
    'logout'				=> 'logout',
    'lookup_by_tag'     => 'Ricerca da Asset Tag',
    'maintenances'          => 'Manutenzioni',
    'manage_api_keys'       => 'Manage API Keys',
    'manufacturer'			=> 'Produttore',
    'manufacturers'			=> 'Produttori',
    'markdown'				=> 'Questo campo consente a <a href="https://help.github.com/articles/github-flavored-markdown/">Gridubdown flavored markdown</a>.',
    'min_amt'				=> 'Min. QTY',
    'min_amt_help'          => 'Minimum number of items that should be available before an alert gets triggered. Leave Min. QTY blank if you do not want to receive alerts for low inventory.',
    'model_no'				=> 'Modello No.',
    'months'				=> 'mesi',
    'moreinfo'				=> 'Altre informazioni',
    'name'					=> 'Nome',
    'new_password'          => 'Nuova password',
    'next'					=> 'Successivo',
    'next_audit_date'		=> 'Prossima data di verifica',
    'last_audit'		    => 'Ultimo controllo',
    'new'					=> 'nuovo!',
    'no_depreciation'		=> 'Non Obsololeto',
    'no_results'			=> 'Nessun risultato.',
    'no'  					=> 'No',
    'notes'  				=> 'Note',
    'order_number'          => 'Numero d\'ordine',
    'page_menu'				=> 'Visualizza _MENU_Items',
    'pagination_info'		=> 'Visualizza _START_ to _END_ of _TOTAL_ articoli',
    'pending'				=> 'In attesa',
    'people'				=> 'Utenti',
    'per_page'				=> 'Risultati per Pagina',
    'previous'				=> 'Precedente',
    'processing'			=> 'In elaborazione',
    'profile'				=> 'Il tuo profilo',
    'purchase_cost'                              => 'Prezzo d\'acquisto',
    'purchase_date'         => 'Data di acquisto',
    'qty'		            => 'Quantità',
    'quantity'		        => 'Quantità',
    'quantity_minimum'      => 'You have :count items below or almost below minimum quantity levels',
    'quickscan_checkin'  	=> 'Check-in a Scansione Rapida',
    'quickscan_checkin_status'  	=> 'Stato Check-in',
    'ready_to_deploy'		=> 'Pronto per il rilascio',
    'recent_activity'		=> 'Attività Recenti',
    'remaining'             => 'Remaining',
    'remove_company'        => 'Rimuovi associazioni azienda',
    'reports'				=> 'Reports',
    'restored'				=> 'ripristinato',
    'restore'				=> 'Ripristina',
    'requestable_models'    => 'Requestable Models',
    'requested'				=> 'Richiesto',
    'requested_date'        => 'Requested Date',
    'requested_assets'      => 'Requested Assets',
    'requested_assets_menu' => 'Requested Assets',
    'request_canceled'      => 'Richiesta annullata',
    'save'  				=> 'Salva',
    'select'				=> 'Seleziona',
    'select_all'            => 'Seleziona tutto',
    'search'				=> 'Cerca',
    'select_category'       => 'Seleziona una categoria',
    'select_department'     => 'Seleziona un Dipartimento',
    'select_depreciation'	=> 'Selezionare un tipo di ammortamento',
    'select_location'		=> 'Seleziona una posizione',
    'select_manufacturer'	=> 'Selezionare un produttore',
    'select_model'			=> 'Selezionare un modello',
    'select_supplier'		=> 'Selezionare un fornitore',
    'select_user'			=> 'Selezionare un utente',
    'select_date'			=> 'Seleziona la data (YYYY-MM-DD)',
    'select_statuslabel'	=> 'Seleziona stato',
    'select_company'    	=> 'Seleziona Azienda',
    'select_asset'    		=> 'Seleziona Asset',
    'settings'				=> 'Impostazioni',
    'show_deleted'  		=> 'Mostra Eliminati',
    'show_current'  		=> 'Visualizza corrente',
    'sign_in'				=> 'Accedi',
    'signature'             => 'Firma',
    'skin'       			=> 'Tema',
    'slack_msg_note'        => 'A slack message will be sent',
    'slack_test_msg'        => 'Oh hai! Sembra che la tua integrazione Slack con Snipe-IT funziona!',
    'some_features_disabled' => 'DEMO: Alcune caratteristiche sono disabilitate in questa modalità.',
    'site_name'				=> 'Nome sito',
    'state'  				=> 'Stato',
    'status_labels'			=> 'Etichetta di Stato',
    'status'    			=> 'Stato',
    'supplier'              => 'Fornitore',
    'suppliers'  			=> 'Fornitori',
    'sure_to_delete'    => 'Sei sicuro di voler eliminare',
    'submit'				=> 'Invia',
    'target'                => 'Assegnatario',
    'toggle_navigation'     => 'Toogle Navigation',
    'time_and_date_display' => 'Visualizzazione del tempo e del tempo',
    'total_assets'			=> 'Assets totali',
    'total_licenses'		=> 'Totale licenze',
    'total_accessories'		=> 'accessori totali',
    'total_consumables'		=> 'consumabili totali',
    'type'  				=> 'Tipo',
    'undeployable'			=> 'Non consegnabile',
    'unknown_admin'			=> 'Amministratore sconosciuto',
    'username_format'		=> 'Formato di nome utente',
    'update'                => 'Aggiorna',
    'upload_filetypes_help'      => 'I tipi di file permessi sono png, gif, jpg, jpeg, doc, docx, pdf, xls, txt, lic, zip, e rar. La dimensione massima di upload è di :size.',
    'uploaded'              => 'Caricato',
    'user'					=> 'Utente',
    'accepted'			    => 'accettato',
    'declined'			    => 'rifiutato',
    'unaccepted_asset_report' => 'Prodotti non accettati',
    'users'                 => 'Utenti',
    'viewall'				=> 'Visualizza tutto',
    'viewassets'  			=> 'Visualizza gli Assets assegnati',
    'viewassetsfor'         => 'View Assets for :name',
    'website'               => 'Sito Web',
    'welcome'				=> 'Benvenuto, :name',
    'years'					=> 'anni',
    'yes' 					=> 'SÌ',
    'zip'  					=> 'Zip',
    'noimage'				=> 'Nessuna immagine caricata o immagine non trovata.',
    'token_expired'         => 'La sessione di modulo è scaduta. Riprova.',
    'login_enabled'         => 'Login Abilitato',
    'audit_due'             => 'In scadenza per l\'audit',
    'audit_overdue'         => 'Scaduto per l\'audit',
    'accept'                => 'Accetta :asset',
    'i_accept'              => 'Accetto',
    'i_decline'             => 'Rifiuto',
    'accept_decline'        => 'Accetta/Rifiuta',
    'sign_tos'              => 'Firma qui sotto per indicare che accetti i termini di servizio:',
    'clear_signature'       => 'Cancella Firma',
    'show_help'             => 'Mostra aiuto',
    'hide_help'             => 'Nascondi aiuto',
    'view_all'              => 'view all',
    'hide_deleted'          => 'Hide Deleted',
    'email'                 => 'Email',
    'do_not_change'         => 'Do Not Change',
    'bug_report'            => 'Report a Bug',
    'user_manual'           => 'User\'s Manual',
    'setup_step_1'          => 'Passo 1',
    'setup_step_2'          => 'Passo 2',
    'setup_step_3'          => 'Passo 3',
    'setup_step_4'          => 'Passo 4',
    'setup_config_check'    => 'Configuration Check',
    'setup_create_database' => 'Crea tabelle database',
    'setup_create_admin'    => 'Crea utente amministratore',
    'setup_done'            => 'Finished!',
    'bulk_edit_about_to'    => 'You are about to edit the following: ',
    'checked_out'           => 'Checked Out',
    'checked_out_to'        => 'Checked out to',
    'fields'                => 'Fields',
    'last_checkout'         => 'Last Checkout',
    'due_to_checkin'        => 'The following :count items are due to be checked in soon:',
    'expected_checkin'      => 'Expected Checkin',
    'reminder_checked_out_items' => 'This is a reminder of the items currently checked out to you. If you feel this list is inaccurate (something is missing, or something appears here that you believe you never received), please email :reply_to_name at :reply_to_address.',
    'changed'               => 'Changed',
    'to'                    => 'To',
    'report_fields_info'    => '<p>Select the fields you would like to include in your custom report, and click Generate. The file (custom-asset-report-YYYY-mm-dd.csv) will download automatically, and you can open it in Excel.</p>
            <p>If you would like to export only certain assets, use the options below to fine-tune your results.</p>',
    'range'                 => 'Range',
    'bom_remark'            => 'Add a BOM (byte-order mark) to this CSV',
    'improvements'          => 'Improvements',
    'information'           => 'Information',
    'permissions'           => 'Permissions',
    'managed_ldap'          => '(Managed via LDAP)',
    'export'                => 'Export',
    'ldap_sync'             => 'LDAP Sync',
    'ldap_user_sync'        => 'LDAP User Sync',
    'synchronize'           => 'Synchronize',
    'sync_results'          => 'Synchronization Results',
    'license_serial'        => 'Serial/Product Key',
    'invalid_category'      => 'Invalid category',
    'dashboard_info'        => 'This is your dashboard. There are many like it, but this one is yours.',
    '60_percent_warning'    => '60% Complete (warning)',
    'dashboard_empty'       => 'It looks like you haven not added anything yet, so we do not have anything awesome to display. Get started by adding some assets, accessories, consumables, or licenses now!',
    'new_asset'             => 'New Asset',
    'new_license'           => 'New License',
    'new_accessory'         => 'New Accessory',
    'new_consumable'        => 'New Consumable',
    'collapse'              => 'Collapse',
    'assigned'              => 'Assigned',
    'asset_count'           => 'Asset Count',
    'accessories_count'     => 'Accessories Count',
    'consumables_count'     => 'Consumables Count',
    'components_count'      => 'Components Count',
    'licenses_count'        => 'Licenses Count',
    'notification_error'    => 'Error:',
    'notification_error_hint' => 'Please check the form below for errors',
    'notification_success'  => 'Success:',
    'notification_warning'   => 'Warning:',
    'notification_info'      => 'Info:',
    'asset_information'     => 'Asset Information',
    'model_name'            => 'Model Name:',
    'asset_name'            => 'Asset Name:',
    'consumable_information' => 'Consumable Information:',
    'consumable_name'       => 'Consumable Name:',
    'accessory_information' => 'Accessory Information:',
    'accessory_name'       => 'Accessory Name:',
    'clone_item'            => 'Clone Item',
    'checkout_tooltip' => 'Check this item out',
    'checkin_tooltip' => 'Check this item in',
    'checkout_user_tooltip' => 'Check this item out to a user',
];
